Learn R Programming

starvz (version 0.8.4)

panel_activenodes: Create the active nodes in memory plot

Description

Use starvz_data to create a line plot of the number of active nodes per type along the application execution time

Usage

panel_activenodes(
  data = NULL,
  step = data$config$activenodes$aggregation$step,
  aggregation = data$config$activenodes$aggregation$active,
  x_start = data$config$limits$start,
  x_end = data$config$limits$end,
  legend = data$config$activenodes$legend
)

Value

A ggplot object

Arguments

data

starvz_data with trace data

step

size in milliseconds for the time aggregation step

aggregation

enable/disable time aggregation for the plot

x_start

X-axis start value

x_end

X-axis end value

legend

enable/disable plot legends

Examples

Run this code
if (FALSE) {
panel_activenodes(data = starvz_sample_lu, step = 100)
}

Run the code above in your browser using DataLab