Learn R Programming

starvz (version 0.8.4)

panel_atree_structure: Create the elimination tree structure plot along time

Description

Use Atree and Application data to create the elimination tree structure plot in a ggplot object and return it

Usage

panel_atree_structure(data = NULL, end_arrow = "ParentEnd")

Value

A ggplot object

Arguments

data

starvz_data with trace data

end_arrow

behavior of the end arrow [ParentEnd, ComputationEnd]

Examples

Run this code
if (FALSE) {
panel_atree_structure(starvz_sample_lu)
}

Run the code above in your browser using DataLab