Learn R Programming

starvz (version 0.8.4)

panel_model_gflops: Create the diagnostig plot for the regression model

Description

Use the starvz Application data to observe how the regression model used in the task anomaly classification fits the data.

Usage

panel_model_gflops(data,
         freeScales = TRUE, model_type = "LOG_LOG")

Value

A ggplot object

Arguments

data

starvz_data with trace data

freeScales

free X,Y scales for each task and resource type combination

model_type

Choose the regression model type to use

Examples

Run this code
if (FALSE) {
panel_model_gflops(data = starvz_sample_sample)
}

Run the code above in your browser using DataLab