Learn R Programming

starvz (version 0.8.4)

panel_st: Create a space time visualization of the application as a Gantt chart

Description

Use the Application trace data to plot the task computations by ResourceId over the execution time. It will select the aggregation mode if requested.

Usage

panel_st(
  data,
  agg = data$config$st$aggregation$active,
  agg_met = data$config$st$aggregation$method
)

Value

A ggplot object

Arguments

data

starvz_data with trace data

agg

boolean Active or not aggregation

agg_met

Aggregation method, possible: static, dynamic, nodes

Examples

Run this code
panel_st(data = starvz_sample_lu)

Run the code above in your browser using DataLab