Use the Application trace data to plot the task computations by ResourceId over the execution time.
panel_st_raw(
data = NULL,
ST.Outliers = data$config$st$outliers,
base_size = data$config$base_size,
expand_x = data$config$expand,
expand_y = data$config$st$expand,
selected_nodes = data$config$selected_nodes,
labels = data$config$st$labels,
alpha = data$config$st$alpha,
idleness = data$config$st$idleness,
taskdeps = data$config$st$tasks$active,
tasklist = data$config$st$tasks$list,
levels = data$config$st$tasks$levels,
makespan = data$config$st$makespan,
abe = data$config$st$abe$active,
pmtoolbounds = data$config$pmtool$bounds$active,
cpb = data$config$st$cpb,
cpb_mpi = data$config$st$cpb_mpi$active,
legend = data$config$st$legend,
x_start = data$config$limits$start,
x_end = data$config$limits$end,
drop_small = data$config$st$drop_small,
runtime = FALSE
)A ggplot object
starvz_data with trace data
enable/disable the anomalous task highlighting
base_size base font size
expand size for scale_x_continuous padding
expand size for scale_y_continuous padding
select only some nodes in some plots
labels: [ALL, 1CPU_per_NODE, 1GPU_per_NODE, FIRST_LAST, NODES_only, NODES_1_in_10, 1CPU_1GPU, ALL_nompi]
alpha value for non-anomalous tasks
enable/disable idleness percentages in the plot
enable/disable task deps path highlighting
list of JobIds to highlight the dependencies
number of dependencies to be shown
enable/disable application makespan at the end of the plot
enable/disable ABE metric
enable/disable pmtool theoretical bounds
enable/disable critical path bound makespan metric
enable/disable critical path bound makespan considering MPI
enable/disable legends
X-axis start value
X-axis end value
Drop states smaller then this value
TODO I think we should create a separated function for it
# \donttest{
panel_st_raw(data = starvz_sample_lu)
# }
Run the code above in your browser using DataLab