Learn R Programming

starvz (version 0.8.4)

panel_utiltreedepth: Create the resource utilization by tree depth plot

Description

Use starvz_data Application and Atree to create a plot that shows the total resource utilization, painted by tree depth level using geom_ribbon

Usage

panel_utiltreedepth(
  data,
  step = data$config$utiltreenode$step,
  x_start = data$config$limits$start,
  x_end = data$config$limits$end,
  legend = data$config$utiltreedepth$legend
)

Value

A ggplot object

Arguments

data

starvz_data with trace data

step

size in milliseconds for the time aggregation step

x_start

X-axis start value

x_end

X-axis end value

legend

enable/disable plot legends

Examples

Run this code
if (FALSE) {
panel_utiltreedepth(starvz_sample_lu, step = 100, legend = TRUE)
}

Run the code above in your browser using DataLab