Learn R Programming

starvz (version 0.8.4)

panel_utiltreenode: Create the resource utilization by tree node plot

Description

Use starvz_data Application and Atree to create a plot that shows the total resource utilization, painted by tree node using geom_ribbon. The colors are reused between nodes, not tied to a specific tree node.

Usage

panel_utiltreenode(
  data = NULL,
  step = data$config$utiltreenode$step,
  x_start = data$config$limits$start,
  x_end = data$config$limits$end
)

Value

A ggplot object

Arguments

data

starvz_data with trace data

step

size in milliseconds for the time aggregation step

x_start

X-axis start value

x_end

X-axis end value

Examples

Run this code
if (FALSE) {
panel_utiltreenode(data = starvz_sample_lu, step = 100)
}

Run the code above in your browser using DataLab