Learn R Programming

starvz (version 0.8.3)

starvz_assemble: Assemble multiple StarVZ panel lists

Description

Take a panel list, or a list of list of panels and assemble it

Usage

starvz_assemble(
  ...,
  config = NULL,
  remove_Y_info = TRUE,
  remove_legends = TRUE
)

Value

The ggplot plot

Arguments

...

Panel list or list of panel lists

config

StarVZ configurations for determaning panels heights

remove_Y_info

remove Y labels for a second and subsequent list of panels

remove_legends

remove legends for a second and subsequent list of panels

Examples

Run this code
# \donttest{
starvz_assemble(starvz_plot_list(starvz_sample_lu),
  config = starvz_sample_lu$config
)
# }

Run the code above in your browser using DataLab