Learn R Programming

starvz (version 0.8.4)

starvz_phase1: Execute StarVZ Phase one.

Description

This function calls all CSV-converter inner-functions to pre-process they into StarVZ files. Although this can be directly used in a folder where all CSV compressed (gzip) files reside, we suggest to use the shell tool starvz or phase1-workflow.sh in the tools/ directory.

Usage

starvz_phase1(
  directory = ".",
  app_states_fun = lu_colors,
  state_filter = 0,
  whichApplication = "",
  input.parquet = "1",
  config_file = NULL
)

Value

ggplot object with all starvz plots

Arguments

directory

Directory of CSV files

app_states_fun

Function to determine application

state_filter

Type of filter

whichApplication

Name of Application

input.parquet

Use or not of parquet files

config_file

StarVZ config structure, this function uses only the app_tasks

Examples

Run this code
if (FALSE) { # requireNamespace("arrow", quietly = TRUE)
# \donttest{
example_folder <- system.file("extdata", "lu_trace", package = "starvz")
starvz_phase1(directory = example_folder)
# }
}

Run the code above in your browser using DataLab