Learn R Programming

starvz (version 0.8.4)

starvz_read_config: Read config files

Description

Read starvz configuration yaml files. This function is design to replace an already existing configuration on starvz data.

Usage

starvz_read_config(file = NULL, warn = TRUE)

Value

A list containing starvz configuration

Arguments

file

The path to a file

warn

Give a warn in case the config file is not found

Examples

Run this code
# \donttest{
example_file <- system.file("extdata", "config.yaml", package = "starvz")
config <- starvz_read_config(example_file)
# }

Run the code above in your browser using DataLab