powered by
Use Atree and Application data to create the elimination tree structure plot in a ggplot object and return it
panel_atree_structure(data = NULL, end_arrow = "ParentEnd")
A ggplot object
starvz_data with trace data
behavior of the end arrow [ParentEnd, ComputationEnd]
if (FALSE) { panel_atree_structure(starvz_sample_lu) }
Run the code above in your browser using DataLab