powered by
Use the starvz Application data to observe how the regression model used in the task anomaly classification fits the data.
panel_model_gflops(data, freeScales = TRUE, model_type = "LOG_LOG")
A ggplot object
starvz_data with trace data
free X,Y scales for each task and resource type combination
Choose the regression model type to use
if (FALSE) { panel_model_gflops(data = starvz_sample_sample) }
Run the code above in your browser using DataLab