powered by
Use starvz_data Application and Atree to create a plot that shows the total resource utilization, painted by tree depth level using geom_ribbon
panel_utiltreedepth( data, step = data$config$utiltreenode$step, x_start = data$config$limits$start, x_end = data$config$limits$end, legend = data$config$utiltreedepth$legend )
A ggplot object
starvz_data with trace data
size in milliseconds for the time aggregation step
X-axis start value
X-axis end value
enable/disable plot legends
if (FALSE) { panel_utiltreedepth(starvz_sample_lu, step = 100, legend = TRUE) }
Run the code above in your browser using DataLab