panel_utiltreenode: Create the resource utilization by tree node plot
Description
Use starvz_data Application and Atree to create a plot that shows the
total resource utilization, painted by tree node using geom_ribbon. The
colors are reused between nodes, not tied to a specific tree node.