powered by
Take a panel list, or a list of list of panels and assemble it
starvz_assemble( ..., config = NULL, remove_Y_info = TRUE, remove_legends = TRUE )
The ggplot plot
Panel list or list of panel lists
StarVZ configurations for determaning panels heights
remove Y labels for a second and subsequent list of panels
remove legends for a second and subsequent list of panels
# \donttest{ starvz_assemble(starvz_plot_list(starvz_sample_lu), config = starvz_sample_lu$config ) # }
Run the code above in your browser using DataLab