powered by
Read starvz configuration yaml files. This function is design to replace an already existing configuration on starvz data.
starvz_read_config(file = NULL, warn = TRUE)
A list containing starvz configuration
The path to a file
Give a warn in case the config file is not found
# \donttest{ example_file <- system.file("extdata", "config.yaml", package = "starvz") config <- starvz_read_config(example_file) # }
Run the code above in your browser using DataLab